Index: Source/core/css/invalidation/StyleInvalidator.cpp |
diff --git a/Source/core/css/invalidation/StyleInvalidator.cpp b/Source/core/css/invalidation/StyleInvalidator.cpp |
index 63541a4ec0f21f02ed40dca3d82ccf785c5241b1..e194b84de6494ef4d5a1e8ce9adf50a4b94cb4ef 100644 |
--- a/Source/core/css/invalidation/StyleInvalidator.cpp |
+++ b/Source/core/css/invalidation/StyleInvalidator.cpp |
@@ -176,9 +176,9 @@ bool StyleInvalidator::invalidate(Element& element, StyleInvalidator::RecursionD |
ASSERT(!recursionData.wholeSubtreeInvalid()); |
element.setNeedsStyleRecalc(LocalStyleChange, StyleChangeReasonForTracing::create(StyleChangeReason::StyleInvalidator)); |
} else if (recursionData.hasInvalidationSets() && someChildrenNeedStyleRecalc) { |
// Clone the LayoutStyle in order to preserve correct style sharing, if possible. Otherwise recalc style. |
if (LayoutObject* renderer = element.layoutObject()) { |
- renderer->setStyleInternal(LayoutStyle::clone(renderer->styleRef())); |
+ renderer->setStyleInternal(ComputedStyle::clone(renderer->styleRef())); |
} else { |
TRACE_STYLE_INVALIDATOR_INVALIDATION_IF_ENABLED(element, PreventStyleSharingForParent); |
element.setNeedsStyleRecalc(LocalStyleChange, StyleChangeReasonForTracing::create(StyleChangeReason::StyleInvalidator)); |
@@ -176,9 +176,9 @@ bool StyleInvalidator::invalidate(Element& element, StyleInvalidator::RecursionD |
element.setNeedsStyleRecalc(LocalStyleChange, StyleChangeReasonForTracing::create(StyleChangeReason::StyleInvalidator)); |
} else if (recursionData.hasInvalidationSets() && someChildrenNeedStyleRecalc) { |
- // Clone the LayoutStyle in order to preserve correct style sharing, if possible. Otherwise recalc style. |
+ // Clone the ComputedStyle in order to preserve correct style sharing, if possible. Otherwise recalc style. |
if (LayoutObject* renderer = element.layoutObject()) { |